camelot.camelot.view.controls.delegates.ComboBoxColumnDelegate

Package camelot :: Package camelot :: Package view :: Package controls :: Module delegates :: Class ComboBoxColumnDelegate |
[hide private]
[frames] | no frames]

# Class ComboBoxColumnDelegate

source code

Instance Methods | [hide private]
__init__(self, choices, parent=None, **kwargs) | source code
qvariantToPython(self, variant) | source code
createEditor(self, parent, option, index) | source code
setEditorData(self, editor, index) | source code
setModelData(self, editor, model, index) | source code